    function iso(x,y,slope,len,cline2)
%
% Program to plot small tangent lines on an isocline
%
% INPUT
% x     = x coordinates of isocline
% y     = y coordinates of isocline 
% slope = slope on isocline
% len   = length of tangent line
% cline2= color of tangent line

    hold on;
    theta=atan(slope);
    for i=1:length(x);
      x1=x(i)-len*cos(theta)/2;
      x2=x(i)+len*cos(theta)/2;
      y1=y(i)-len*sin(theta)/2;
      y2=y(i)+len*sin(theta)/2;
      plot([x1 x2],[y1 y2],cline2);
    end;
